@@ -1,9 +1,9 @@
 ;;; ess-cust.el --- Customize variables for ESS
 
-;; Copyright (C) 1997--2005 A.J. Rossini, Rich M. Heiberger, Martin
+;; Copyright (C) 1997--2006 A.J. Rossini, Rich M. Heiberger, Martin
 ;;	Maechler, Kurt Hornik, Rodney Sparapani, and Stephen Eglen.
 
-;; Original Author: A.J. Rossini <rossini@u.washington.edu>
+;; Original Author: A.J. Rossini <blindglobe@gmail.com>
 ;; Created: 05 June 2000
 ;; Maintainers: ESS-core <ESS-core@stat.math.ethz.ch>
 
@@ -126,7 +126,7 @@
 
 ;; Variables (not user-changeable)
 
-(defvar ess-version "5.2.11"
+(defvar ess-version "5.3.0"
   "Version of ESS currently loaded.")
 
 (defvar no-doc
@@ -256,6 +256,14 @@ If this is a relative file name, it is relative to `ess-history-directory'."
   :group 'ess
   :type 'boolean)
 
+
+(defcustom ess-use-inferior-program-name-in-buffer-name nil
+  "*For R, use e.g., 'R-2.1.0' or 'R-devel' (the program name) for buffer name.
+Avoids the plain dialect name."
+  :group 'ess
+  :type 'boolean)
+
+
 (defcustom ess-S-assign " <- "
   "*String to be used for left assignment in all S dialects.
  Used by \\[ess-smart-underscore]."
@@ -506,7 +514,8 @@ GNU, BSD, ...) map onto different settings for variables."
 
 ;;*;; Variables controlling behaviour of dump files
 
-(defcustom ess-source-directory "/tmp/"
+(defcustom ess-source-directory
+  (if ess-microsoft-p (getenv "TEMP")  "/tmp/")
   "*Directory in which to place dump files.
 This can be a string (an absolute directory name ending in a slash) or
 a lambda expression of no arguments which will return a suitable string
@@ -719,13 +728,14 @@ file."
     "c:/progra~1/Insightful/splus61se"
     "c:/progra~1/Insightful/splus62se"
     "c:/progra~1/Insightful/splus70"
-    "c:/progra~1/Insightful/splus71")
+    "c:/progra~1/Insightful/splus71"
+    "c:/progra~1/Insightful/splus80")
   "*List of possible values of the environment variable SHOME for recent
 releases of S-Plus.  These are the default locations for several
 current and recent releases of S-Plus.  If any of these pathnames
 correspond to a directory on your machine, running the function
 `ess-sqpe-versions-create' will create a function, for example, `M-x
-splus62', that will start the corresponding version Sqpe inside an
+splus70', that will start the corresponding version Sqpe inside an
 emacs buffer in iESS[S] mode.  If you have versions of S-Plus in
 locations other than these default values, redefine this variable with
 a `custom-set-variables' statement in your site-start.el or .emacs
@@ -822,10 +832,10 @@ different computer."
 
 (if ess-microsoft-p
     (defcustom inferior-S+6-program-name
-      "c:/progra~1/insigh~1/splus6/cmd/Splus.exe"
+      "c:/progra~1/insigh~1/splus70/cmd/Splus.exe"
       "*Program name for invoking an external GUI S+6 for Windows.
 The default value is correct for a default installation of
-S-Plus 6.0.3 Release 2 and with bash as the shell.
+S-Plus 7.0 and with bash as the shell.
 For any other version or location, change this value in ess-site.el or
 site-start.el.  Use the 8.3 version of the pathname.
 Use double backslashes if you use the msdos shell."
@@ -861,17 +871,17 @@ in S+6 for Windows Commands window and in Sqpe+6 for Windows buffer."
   :type 'string)
 
 (defcustom inferior-Sqpe+6-program-name
-  "c:/progra~1/insigh~1/splus6/cmd/Sqpe.exe"
+  "c:/progra~1/insigh~1/splus70/cmd/Sqpe.exe"
   "*Program name for invoking an inferior ESS with Sqpe+6() for Windows."
   :group 'ess-S
   :type 'string)
 
 ;;; SJE - avoid mismatch by changing default nil to ""
 (defcustom inferior-Sqpe+6-SHOME-name
-  (if ess-microsoft-p "c:/progra~1/insigh~1/splus6" "")
+  (if ess-microsoft-p "c:/progra~1/insigh~1/splus70" "")
   "*SHOME name for invoking an inferior ESS with Sqpe+6() for Windows.
 The default value is correct for a default installation of
-S-Plus 6.0.3 Release 2.  For any other version or location,
+S-Plus 7.0.  For any other version or location,
 change this value in ess-site.el or site-start.el.  Use the 8.3
 version of the pathname."
   :group 'ess-S
@@ -997,6 +1007,17 @@ for editing and then to be returned to the process.")
 
 
 
+;;;;; names for S-Plus help files on MS-Windows
+
+(defcustom inferior-ess-help-filetype nil
+  "S-Plus and Sqpe for Windows use the \"chm\" (compiled html) filetype
+for help files.  The default value is nil for other systems."
+  :group 'ess-proc
+  :type 'string)
+(make-variable-buffer-local 'inferior-ess-help-filetype)
+(setq-default inferior-ess-help-filetype nil)
+
+
 ;;;;; names for communication using MS-Windows 9x/NT ddeclient mechanism
 
 (defcustom inferior-ess-ddeclient nil
@@ -1055,7 +1076,9 @@ If you wish to pass arguments to a process, see e.g. `inferior-R-args'.")
 
 (defcustom inferior-ess-primary-prompt "[a-zA-Z0-9() ]*> ?"
   "Regular expression used by `ess-mode' to detect the primary prompt.
-Do not anchor to bol with `^'.")
+Do not anchor to bol with `^'."
+  :group 'ess-proc
+  :type 'string)
 
 (make-variable-buffer-local 'inferior-ess-primary-prompt)
 (setq-default inferior-ess-primary-prompt "[a-zA-Z0-9() ]*> ?")
@@ -1063,7 +1086,9 @@ Do not anchor to bol with `^'.")
 (defcustom inferior-ess-secondary-prompt "+ ?"
   "Regular expression used by ess-mode to detect the secondary prompt.
 (This is issued by S to continue an incomplete expression). Do not
-anchor to bol with `^'.")
+anchor to bol with `^'."
+  :group 'ess-proc
+  :type 'string)
 
 (make-variable-buffer-local 'inferior-ess-secondary-prompt)
 (setq-default inferior-ess-secondary-prompt "+ ?")
@@ -1113,9 +1138,7 @@ of Emacs until the code has been successfully evaluated."
   :group 'ess-proc
   :type '(choice (const nil) string))
 
-;; defconst ess-local-process-name now done in S.el
-
-(defcustom ess-process-name-list nil
+(defvar ess-process-name-list nil
   "Alist of active ESS processes.")
 
 ;;*;; Inferior ESS commands
