@@ -42,12 +42,12 @@
 (if (and (not (boundp 'emacs-major-version))
 	 (string-match "^[0-9]+" emacs-version))
     (setq emacs-major-version
-	  (string-to-int (substring emacs-version
+	  (string-to-number (substring emacs-version
 				    (match-beginning 0) (match-end 0)))))
 (if (and (not (boundp 'emacs-minor-version))
 	 (string-match "^[0-9]+\\.\\([0-9]+\\)" emacs-version))
     (setq emacs-minor-version
-	  (string-to-int (substring emacs-version
+	  (string-to-number (substring emacs-version
 				    (match-beginning 1) (match-end 1)))))
 
 ;;; Define a function to make it easier to check which version we're
@@ -240,6 +240,13 @@ and replace a sub-expression, e.g.
 	   (w32-system-shell-p (getenv "COMSPEC")))))
 )
 
+;; XEmacs need this (unless configured with  --with-mule=yes)
+(if (not (boundp 'enable-multibyte-characters))
+    (defvar enable-multibyte-characters nil
+      "Non-nil means the buffer contents are regarded as multi-byte characters.
+ This concept is handled completely differently on Xemacs."))
+
+
 ;; XEmacs on Windows needs this
 (if (and ess-microsoft-p
 	 (not (fboundp 'w32-short-file-name)))
