@@ -63,6 +63,11 @@
 (autoload 'ess-search-list		"ess-inf" "(autoload)" nil)
 (autoload 'ess-get-object-list		"ess-inf" "(autoload)" nil)
 
+(autoload 'ess-ddeclient-p		"ess-inf" "(autoload)" nil)
+
+(autoload 'ess-display-help-on-object-ddeclient "ess-dde" "(autoload)" nil)
+
+
  ; ess-help-mode
 ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
 ;;;; In this section:
@@ -92,7 +97,7 @@ Utility used in \\[ess-display-help-on-object]."
 		    (ess-write-to-dribble-buffer
 		     (format "(ess-help-bogus-buffer-p %s)" (buffer-name))))
 
-		(let 
+		(let
 		    ((PM (point-min))
 		     (case-fold-search t) )
 		  (or  ;; evaluate up to first non-nil (or end):
@@ -115,127 +120,141 @@ Utility used in \\[ess-display-help-on-object]."
       ;; else
       res)))
 
-;;*;; Access function for displaying help
-
 (defun ess-display-help-on-object (object)
   "Display documentation for OBJECT in another window.
 If prefix arg is given, forces a query of the  ESS process for the help
 file.  Otherwise just pops to an existing buffer if it exists.
-Uses the variable `inferior-ess-help-command' for the actual help command."
-  (interactive (ess-find-help-file "Help on: "))
-  (let* ((hb-name (concat "*help["
-			  ess-current-process-name
-			  "](" object ")*"))
-	 (old-hb-p	(get-buffer hb-name))
-	 (curr-win-mode major-mode)
-	 (tbuffer	(get-buffer-create hb-name))
-	 (curr-help-command		inferior-ess-help-command)
-	 ;;-- pass the buffer-local 'ess-help-sec-..'  to the ess-help buffer:
-	 (curr-help-sec-regex		ess-help-sec-regex)
-	 (curr-help-sec-keys-alist	ess-help-sec-keys-alist)
-	 (curr-help-syntax-table	(syntax-table))
-	 (alist		ess-local-customize-alist))
+Uses the variable `inferior-ess-help-command' for the actual help command.
+Prompts for the object name based on the cursor location for all cases
+except the S-Plus GUI.  With S-Plus on Windows (both GUI and in an inferior
+emacs buffer) the GUI help window is used."
+  (interactive 
+   (if (ess-ddeclient-p)
+       (list (read-string "Help on: "))
+     (ess-find-help-file "Help on: ")))
 
-    (set-buffer tbuffer)
-    (ess-setq-vars-local (eval alist))
-    (setq ess-help-sec-regex	  curr-help-sec-regex)
-    (setq ess-help-sec-keys-alist curr-help-sec-keys-alist)
-    ;; see above, do same for inferior-ess-help-command... (i.e. remove
-    ;; hack, restore old code :-).
+  (if (or (ess-ddeclient-p)
+	  (equal inferior-ess-help-filetype "chm"))
+      (if (ess-ddeclient-p)
+	  (ess-display-help-on-object-ddeclient object) ;; ddeclient version
+	(ess-eval-linewise (concat "help(" object ")"))) ;; "chm" version
 
-    (if (or (not old-hb-p)
-	    current-prefix-arg
-	    (ess-help-bogus-buffer-p old-hb-p nil nil 'debug)
-	    )
+    ;; else: "normal", non-DDE behavior:
+    (let* ((hb-name (concat "*help["
+			    ess-current-process-name
+			    "](" object ")*"))
+	   (old-hb-p	(get-buffer hb-name))
+	   (curr-win-mode major-mode)
+	   (tbuffer	(get-buffer-create hb-name))
+	   (curr-help-command		inferior-ess-help-command)
+	   ;;-- pass the buffer-local 'ess-help-sec-..'  to the ess-help buffer:
+	   (curr-help-sec-regex		ess-help-sec-regex)
+	   (curr-help-sec-keys-alist	ess-help-sec-keys-alist)
+	   (curr-help-syntax-table	(syntax-table))
+	   (curr-help-filetype	        inferior-ess-help-filetype)
+	   (alist		ess-local-customize-alist))
 
-	;; Ask the corresponding ESS process for the help file:
-	(progn
-	  (if buffer-read-only (setq buffer-read-only nil))
-	  (delete-region (point-min) (point-max))
-	  (ess-help-mode)
-	  (setq ess-local-process-name ess-current-process-name)
-	  (ess-command (format curr-help-command object) tbuffer)
-	  ;; was inferior-ess-help-command
+      (set-buffer tbuffer)
+      (ess-setq-vars-local (eval alist))
+      (setq ess-help-sec-regex	  curr-help-sec-regex)
+      (setq ess-help-sec-keys-alist curr-help-sec-keys-alist)
+      (setq inferior-ess-help-filetype curr-help-filetype)
+      ;; see above, do same for inferior-ess-help-command... (i.e. remove
+      ;; hack, restore old code :-).
 
-	  (ess-help-underline)
-	  ;; Stata is clean, so we get a big BARF from this.
-	  (if (not (string= ess-language "STA"))
-	      (ess-nuke-help-bs))
+      (if (or (not old-hb-p)
+	      current-prefix-arg
+	      (ess-help-bogus-buffer-p old-hb-p nil nil 'debug)
+	      )
 
-	  (goto-char (point-min))))
+	  ;; Ask the corresponding ESS process for the help file:
+	  (progn
+	    (if buffer-read-only (setq buffer-read-only nil))
+	    (delete-region (point-min) (point-max))
+	    (ess-help-mode)
+	    (setq ess-local-process-name ess-current-process-name)
+	    (ess-command (format curr-help-command object) tbuffer)
+	    ;; was inferior-ess-help-command
 
-    (save-excursion
-      (let ((PM (point-min))
-	    (nodocs (ess-help-bogus-buffer-p (current-buffer) nil 'give-match ))
-	    )
-	(goto-char PM)
-	(if (and nodocs
-		 ess-help-kill-bogus-buffers)
-	    (progn
-	      (if (not (listp nodocs))
-		  (setq nodocs (list PM (point-max))))
-	      (ess-write-to-dribble-buffer
-	       (format "(ess-help: error-buffer '%s' nodocs (%d %d)\n"
-		       (buffer-name) (car nodocs) (cadr nodocs)))
-	      ;; Avoid using 'message here -- may be %'s in string
-	      ;;(princ (buffer-substring (car nodocs) (cadr nodocs)) t)
-	      ;; MM [3/2000]: why avoid?  Yes, I *do* want message:
-	      (message "%s" (buffer-substring (car nodocs) (cadr nodocs)))
-	      ;; ^^^ fixme : remove new lines from the above {and abbrev.}
-	      (ding)
-	      (kill-buffer tbuffer))
+	    (ess-help-underline)
+	    ;; Stata is clean, so we get a big BARF from this.
+	    (if (not (string= ess-language "STA"))
+		(ess-nuke-help-bs))
 
-	  ;; else : show the help buffer.
+	    (goto-char (point-min))))
 
-	  ;; Check if this buffer describes where help can be found in
-	  ;; various packages. (R only).  This is a kind of bogus help
-	  ;; buffer, but it should not be killed immediately even if
-	  ;; ess-help-kill-bogus-buffers is t.
+      (save-excursion
+	(let ((PM (point-min))
+	      (nodocs
+	       (ess-help-bogus-buffer-p (current-buffer) nil 'give-match )))
+	  (goto-char PM)
+	  (if (and nodocs
+		   ess-help-kill-bogus-buffers)
+	      (progn
+		(if (not (listp nodocs))
+		    (setq nodocs (list PM (point-max))))
+		(ess-write-to-dribble-buffer
+		 (format "(ess-help: error-buffer '%s' nodocs (%d %d)\n"
+			 (buffer-name) (car nodocs) (cadr nodocs)))
+		;; Avoid using 'message here -- may be %'s in string
+		;;(princ (buffer-substring (car nodocs) (cadr nodocs)) t)
+		;; MM [3/2000]: why avoid?  Yes, I *do* want message:
+		(message "%s" (buffer-substring (car nodocs) (cadr nodocs)))
+		;; ^^^ fixme : remove new lines from the above {and abbrev.}
+		(ding)
+		(kill-buffer tbuffer))
 
-	  ;; e.g. if within R, the user does:
-	  
-	  ;; > options("help.try.all.packages" = TRUE)
+	    ;; else : show the help buffer.
 
-	  ;; > ?rlm
+	    ;; Check if this buffer describes where help can be found in
+	    ;; various packages. (R only).  This is a kind of bogus help
+	    ;; buffer, but it should not be killed immediately even if
+	    ;; ess-help-kill-bogus-buffers is t.
 
-	  ;; then a list of packages for where ?rlm is defined is
-	  ;; shown.  (In this case, rlm is in package MASS).  This
-	  ;; help buffer is then renamed *help[R](rlm in packages)* so
-	  ;; that after MASS is loaded, ?rlm will then show 
-	  ;; *help[R](rlm)*
+	    ;; e.g. if within R, the user does:
 
-	  (if (equal inferior-ess-program inferior-R-program-name)
-	      ;; this code should be used only for R processes.
-	      (save-excursion
-		(goto-char (point-min))
-		(if (looking-at "Help for topic")
-		    (let 
-			( (newbuf 
-			   (concat "*help[" ess-current-process-name
-				   "](" object " in packages)*")))
-		      ;; if NEWBUF already exists, remove it.
-		      (if (get-buffer newbuf)
-			  (kill-buffer newbuf))
-		      (rename-buffer  newbuf)))))
+	    ;; > options("help.try.all.packages" = TRUE)
 
-	  ;;dbg (ess-write-to-dribble-buffer
-	  ;;dbg	 (format "(ess-help '%s' before switch-to..\n" hb-name)
-	  (let ((special-display-regexps
-		 (if ess-help-own-frame '(".") nil))
-		(special-display-frame-alist ess-help-frame-alist)
-		(special-display-function
-		 (if (eq ess-help-own-frame 'one)
-		     'ess-help-own-frame
-		   special-display-function)))
-	    (if (eq curr-win-mode 'ess-help-mode)
-		(if ess-help-own-frame
-		    (pop-to-buffer tbuffer)
-		  (switch-to-buffer tbuffer))
-	      (ess-display-temp-buffer tbuffer)))
-	  (if curr-help-syntax-table
-	      (set-syntax-table curr-help-syntax-table))
-	  (set-buffer-modified-p 'nil)
-	  (toggle-read-only t))))))
+	    ;; > ?rlm
+
+	    ;; then a list of packages for where ?rlm is defined is
+	    ;; shown.  (In this case, rlm is in package MASS).  This
+	    ;; help buffer is then renamed *help[R](rlm in packages)* so
+	    ;; that after MASS is loaded, ?rlm will then show
+	    ;; *help[R](rlm)*
+
+	    (if (equal inferior-ess-program inferior-R-program-name)
+		;; this code should be used only for R processes.
+		(save-excursion
+		  (goto-char (point-min))
+		  (if (looking-at "Help for topic")
+		      (let
+			  ( (newbuf
+			     (concat "*help[" ess-current-process-name
+				     "](" object " in packages)*")))
+			;; if NEWBUF already exists, remove it.
+			(if (get-buffer newbuf)
+			    (kill-buffer newbuf))
+			(rename-buffer  newbuf)))))
+
+	    ;;dbg (ess-write-to-dribble-buffer
+	    ;;dbg	 (format "(ess-help '%s' before switch-to..\n" hb-name)
+	    (let ((special-display-regexps
+		   (if ess-help-own-frame '(".") nil))
+		  (special-display-frame-alist ess-help-frame-alist)
+		  (special-display-function
+		   (if (eq ess-help-own-frame 'one)
+		       'ess-help-own-frame
+		     special-display-function)))
+	      (if (eq curr-win-mode 'ess-help-mode)
+		  (if ess-help-own-frame
+		      (pop-to-buffer tbuffer)
+		    (switch-to-buffer tbuffer))
+		(ess-display-temp-buffer tbuffer)))
+	    (if curr-help-syntax-table
+		(set-syntax-table curr-help-syntax-table))
+	    (set-buffer-modified-p 'nil)
+	    (toggle-read-only t)))))))
 
 (defvar ess-help-frame nil
   "Stores the frame used for displaying R help buffers.")
@@ -276,17 +295,8 @@ Uses the variable `inferior-ess-help-command' for the actual help command."
 
 
 (defvar ess-help-sec-map nil "Sub-keymap for ESS help mode.")
-(if ess-help-sec-map
-    nil
-  (setq ess-help-sec-map (make-sparse-keymap))
-  (mapcar '(lambda (key)
-	    (define-key ess-help-sec-map (char-to-string key)
-	      'ess-skip-to-help-section))
-	    (mapcar 'car ess-help-sec-keys-alist))
-  (define-key ess-help-sec-map "?" 'ess-describe-sec-map)
-  (define-key ess-help-sec-map ">" 'end-of-buffer)
-  (define-key ess-help-sec-map "<" 'beginning-of-buffer)
-)
+;; this breaks "s ?" rather than to fix any (unbroken !) thing:
+;; (make-variable-buffer-local 'ess-help-sec-map)
 
 (defvar ess-help-mode-map nil "Keymap for ESS help mode.")
 (if ess-help-mode-map
@@ -295,15 +305,16 @@ Uses the variable `inferior-ess-help-command' for the actual help command."
   (suppress-keymap ess-help-mode-map)	; suppress all usual "printing" characters
   (define-key ess-help-mode-map " " 'scroll-up)
   (define-key ess-help-mode-map "b" 'scroll-down)
+  (define-key ess-help-mode-map "\177" 'scroll-down) ; DEL
   (define-key ess-help-mode-map "q" 'ess-switch-to-end-of-ESS)
   (define-key ess-help-mode-map "\C-m" 'next-line)
-  (define-key ess-help-mode-map "\177" 'scroll-down) ; DEL
-  (define-key ess-help-mode-map "s" ess-help-sec-map)
+  ;; (define-key ess-help-mode-map "s" ess-help-sec-map)
   (define-key ess-help-mode-map "h" 'ess-display-help-on-object)
 ;; TODO: `electric mouse-2'
 ;; (define-key ess-help-mode-map [mouse-2] 'ess-display-help-on-object)
   (define-key ess-help-mode-map "l" 'ess-eval-line-and-step)
   (define-key ess-help-mode-map "r" 'ess-eval-region-and-go)
+  (define-key ess-help-mode-map "f" 'ess-eval-function-or-paragraph-and-step)
   (define-key ess-help-mode-map "n" 'ess-skip-to-next-section)
   (define-key ess-help-mode-map "p" 'ess-skip-to-previous-section)
   (define-key ess-help-mode-map "/" 'isearch-forward)
@@ -312,7 +323,7 @@ Uses the variable `inferior-ess-help-command' for the actual help command."
   (define-key ess-help-mode-map "x" 'ess-kill-buffer-and-go)
   (define-key ess-help-mode-map "k" 'kill-buffer)
   (define-key ess-help-mode-map "?" 'ess-describe-help-mode)
-  ;;-- those should be "inherited" from ess-mode-map :
+  ;;-- those should be "inherited" from ess-mode-map ( ./ess-mode.el )
   (define-key ess-help-mode-map "\C-c\C-s" 'ess-switch-process)
   (define-key ess-help-mode-map "\C-c\C-r" 'ess-eval-region)
   (define-key ess-help-mode-map "\C-c\M-r" 'ess-eval-region-and-go)
@@ -332,9 +343,9 @@ Uses the variable `inferior-ess-help-command' for the actual help command."
 ;; One reason for the following menu is to <TEACH> the user about key strokes
 (defvar ess-help-mode-menu
   (list "ESS-help"
+	["Search Forward"		isearch-forward t]
 	["Next Section"			ess-skip-to-next-section t]
 	["Previous Section"		ess-skip-to-previous-section t]
-	["Search Forwards"		isearch-forward t]
 	["Help on Section Skipping"	ess-describe-sec-map t]
 	["Beginning of Buffer"		beginning-of-buffer t]
 	["End of Buffer"		end-of-buffer t]
@@ -342,14 +353,16 @@ Uses the variable `inferior-ess-help-command' for the actual help command."
 	["Help on ..."			ess-display-help-on-object t]
 	"-"
 	["Eval Line"			ess-eval-line-and-step t]
+	["Eval Paragraph & step" 	ess-eval-paragraph-and-step t]
 	["Eval Region & Go"		ess-eval-region-and-go t]
 	["Switch to ESS Process"	ess-switch-to-ESS t]
+	["Switch to End of ESS Proc."	ess-switch-to-end-of-ESS t]
+	["Switch _the_ Process"		ess-switch-process t]
 	"-"
 	["Describe ESS-help Mode"	ess-describe-help-mode t]
 	"-"
 	["Kill Buffer"			kill-buffer t]
 	["Kill Buffer & Go"		ess-kill-buffer-and-go t]
-	["Back to end of ESS Pr."	ess-switch-to-end-of-ESS t]
 	)
   "Menu used in ess-help mode.")
 
@@ -380,6 +393,20 @@ Other keybindings are as follows:
 		    "Menu keymap for ess-help mode." ess-help-mode-menu)
   (easy-menu-add ess-help-mode-menu-map ess-help-mode-map)
 
+  ;; Add the keys for navigating among sections; this is done
+  ;; dynamically since different languages (e.g. S vs R) have different
+  ;; section headings.
+
+  (setq ess-help-sec-map (make-sparse-keymap))
+  (mapcar '(lambda (key)
+	    (define-key ess-help-sec-map (char-to-string key)
+	      'ess-skip-to-help-section))
+	    (mapcar 'car ess-help-sec-keys-alist))
+  (define-key ess-help-sec-map "?" 'ess-describe-sec-map)
+  (define-key ess-help-sec-map ">" 'end-of-buffer)
+  (define-key ess-help-sec-map "<" 'beginning-of-buffer)
+  (define-key ess-help-mode-map "s" ess-help-sec-map)
+
   (run-hooks 'ess-help-mode-hook))
 
 ;;*;; User commands defined in ESS help mode
@@ -429,23 +456,24 @@ to see which keystrokes find which sections."
 (defun ess-describe-sec-map nil
   "Display help for the `s' key."
   (interactive)
-  (describe-function 'ess-skip-to-help-section)
-  (save-excursion
-    (set-buffer "*Help*")
-    (toggle-read-only nil)
-    (goto-char (point-max))
-    (insert "\n\nCurrently defined keys are:
+  (let ((keys-alist ess-help-sec-keys-alist))
+    (describe-function 'ess-skip-to-help-section)
+    (save-excursion
+      (set-buffer "*Help*")
+      (toggle-read-only nil)
+      (goto-char (point-max))
+      (insert "\n\nCurrently defined keys are:
 
 Keystroke    Section
 ---------    -------\n")
-    (mapcar '(lambda (cs) (insert "    "
-				  (car cs)
-				  "	   "
-				  (cdr cs) "\n"))
-	    ess-help-sec-keys-alist)
-    (insert "\nFull list of key definitions:\n"
-	    (substitute-command-keys
-	     "\\{ess-help-sec-map}"))))
+      (mapcar '(lambda (cs) (insert "	 "
+				    (car cs)
+				    "	   "
+				    (cdr cs) "\n"))
+	      keys-alist)
+      (insert "\nFull list of key definitions:\n"
+	      (substitute-command-keys
+	       "\\{ess-help-sec-map}")))))
 
 (defun ess-read-helpobj-name-default (olist)
   ;;; Returns the object name at point, or else the name of the
@@ -562,7 +590,7 @@ Stata or XLispStat for additional information."
 	   'ess-keep-dump-files
 	   'ess-source-directory)
      nil
-     (lambda () (goto-char (point-max)) (insert-buffer "*ESS*")))))
+     (lambda () (goto-char (point-max)) (insert-buffer-substring "*ESS*")))))
 
 
 ;;; Provide
