@@ -31,10 +31,10 @@
 ;;; Variables
 
 (defconst ess-latex-minor-mode-RCS-Id
-  "$Id: ess-latex.el,v 1.1 1999/09/11 04:06:14 ess Exp $")
+  "Imported to ESS Subversion repository and RCS ids not maintained.")
 
 (defconst ess-latex-minor-mode-RCS-Name
-  "$Name:  $")
+  " ")
 
 (defvar ess-latex-minor-mode-prefix "\M-n"
   "*Prefix key to use for noweb mode commands.
@@ -484,14 +484,15 @@ otherwise."
              (setq mode (concat
                          (downcase (buffer-substring beg end))
                          "-mode"))
-             (if (and (>= (length mode) 11)
+             (if ;(and 
+		 (>= (length mode) 11)
                       (progn
                         (if
                             (equal (substring mode -10 -5) "-mode")
                             (setq mode (substring mode 0 -5)))
                         (if
                             (equal (substring mode 0 5) "mode:")
-                            (setq mode (substring mode 6))))))
+                            (setq mode (substring mode 6)))))
              (intern mode))))))
 
 (defun ess-latex-find-chunk-index-buffer ()
