@@ -1,7 +1,7 @@
 ;;; ess-mode.el --- Support for editing ESS source code
 
 ;; Copyright (C) 1989-1994 Doug Bates, Ed Kademan, Frank Ritter, David Smith.
-;; Copyright (C) 1997--2005 A.J. Rossini, Rich M. Heiberger, Martin
+;; Copyright (C) 1997--2006 A.J. Rossini, Rich M. Heiberger, Martin
 ;;	Maechler, Kurt Hornik, Rodney Sparapani, and Stephen Eglen.
 
 ;; Original Author: David Smith <dsmith@stats.adelaide.edu.au>
@@ -47,17 +47,21 @@
 (autoload 'ess-read-object-name		"ess-inf" "" nil)
 (autoload 'ess-list-object-completions	"ess-inf" "" nil)
 
+(autoload 'ess-eval-buffer		"ess-inf" "" nil)
+(autoload 'ess-eval-buffer-and-go	"ess-inf" "" nil)
+(autoload 'ess-eval-function		"ess-inf" "" nil)
+(autoload 'ess-eval-function-and-go	"ess-inf" "" nil)
+(autoload 'ess-eval-function-or-paragraph-and-step
+                                        "ess-inf" "" nil)
+(autoload 'ess-eval-line		"ess-inf" "" nil)
+(autoload 'ess-eval-line-and-go		"ess-inf" "" nil)
+(autoload 'ess-eval-line-and-step	"ess-inf" "" nil)
 (autoload 'ess-eval-linewise		"ess-inf" "" nil)
 (autoload 'ess-eval-paragraph		"ess-inf" "" nil)
+(autoload 'ess-eval-paragraph-and-go    "ess-inf" "" nil)
+(autoload 'ess-eval-paragraph-and-step  "ess-inf" "" nil)
 (autoload 'ess-eval-region		"ess-inf" "" nil)
-(autoload 'ess-eval-buffer		"ess-inf" "" nil)
-(autoload 'ess-eval-function		"ess-inf" "" nil)
-(autoload 'ess-eval-line		"ess-inf" "" nil)
-(autoload 'ess-eval-line-and-step	"ess-inf" "" nil)
 (autoload 'ess-eval-region-and-go	"ess-inf" "" nil)
-(autoload 'ess-eval-buffer-and-go	"ess-inf" "" nil)
-(autoload 'ess-eval-function-and-go	"ess-inf" "" nil)
-(autoload 'ess-eval-line-and-go		"ess-inf" "" nil)
 
 (autoload 'ess-load-file		"ess-inf" "" nil)
 (autoload 'ess-switch-process		"ess-inf" "" nil)
@@ -73,6 +77,8 @@
 (autoload 'ess-object-modtime		"ess-inf" "" nil)
 (autoload 'ess-quit			"ess-inf" "" nil)
 
+(autoload 'ess-ddeclient-p		"ess-inf" "(autoload)" nil)
+(autoload 'ess-dump-object-ddeclient	"ess-dde" "(autoload)" nil)
 
 (defun ess-line-end-position (&optional N)
   "return the 'point' at the end of N lines. N defaults to 1, i.e., current line."
@@ -132,6 +138,9 @@
   (define-key ess-mode-map "\C-c\M-b"	'ess-eval-buffer-and-go)
   (define-key ess-mode-map "\C-c\C-f"	'ess-eval-function)
   (define-key ess-mode-map "\C-c\M-f"	'ess-eval-function-and-go)
+  (define-key ess-mode-map "\C-c\C-c"	'ess-eval-function-or-paragraph-and-step)
+  (define-key ess-mode-map "\C-c\C-p"	'ess-eval-paragraph-and-step)
+  (define-key ess-mode-map "\C-c\M-p"	'ess-eval-paragraph-and-go)
   (define-key ess-mode-map "\M-\C-x"	'ess-eval-function)
   (define-key ess-mode-map "\C-c\C-n"	'ess-eval-line-and-step)
   (define-key ess-mode-map "\C-c\C-j"	'ess-eval-line)
@@ -171,11 +180,13 @@
  '("ESS" ; ESS-mode
    ["What is this? (beta)"    ess-mouse-me			t]
    ["Load file"	 ess-load-file t]
+   ["Eval func/para & step" ess-eval-function-or-paragraph-and-step t]
    ("Eval and Go"
     ["Eval buffer"	ess-eval-buffer-and-go		  t]
     ["Eval region"	ess-eval-region-and-go		  t]
     ["Eval function"	ess-eval-function-and-go	  t]
     ["Eval line"	ess-eval-line-and-go		  t]
+    ["Eval paragraph"   ess-eval-paragraph-and-go	  t]
     ["Eval chunk"	ess-eval-chunk-and-go	 noweb-mode]
     ["Eval thread"	ess-eval-thread-and-go	 noweb-mode]
     ["About"		(ess-goto-info "Evaluating code") t]
@@ -184,9 +195,12 @@
     ["Eval buffer"	ess-eval-buffer			  t]
     ["Eval region"	ess-eval-region			  t]
     ["Eval function"	ess-eval-function		  t]
+    ["Eval func/para & step" ess-eval-function-or-paragraph-and-step t]
     ["Enter expression" ess-execute-in-tb		  t]
     ["Eval line"	ess-eval-line			  t]
     ["Eval line & step" ess-eval-line-and-step		  t]
+    ["Eval paragraph"   ess-eval-paragraph		  t]
+    ["Eval para. & step" ess-eval-paragraph-and-step	  t]
     ["Eval chunk"	ess-eval-chunk		 noweb-mode]
     ["Eval thread"	ess-eval-thread		 noweb-mode]
     ["About"		(ess-goto-info "Evaluating code") t]
@@ -342,7 +356,6 @@ Variables controlling indentation style:
 Furthermore, \\[ess-set-style] command enables you to set up predefined ess-mode
 indentation style. At present, predefined style are `BSD', `GNU', `K&R', `C++',
 `CLB' (quoted from C language style)."
-  (interactive)
   (kill-all-local-variables) ;; NOTICE THIS!
   (ess-setq-vars-local alist)
   (ess-write-to-dribble-buffer
@@ -452,6 +465,7 @@ indentation style. At present, predefined style are `BSD', `GNU', `K&R', `C++',
 	      "\\)" ;;--------end outer Either/Or-------
 
 	      "\\(" space "\\s<.*\\s>\\)*"	; whitespace, comment
+	      ;; FIXME: in principle we should skip 'definition *= *' here
 	      space "function\\s-*(" ; whitespace, function keyword, parenthesis
 	      ))
      )
@@ -470,13 +484,16 @@ indentation style. At present, predefined style are `BSD', `GNU', `K&R', `C++',
 
 ); {end let}
 
-(defun ess-beginning-of-function ()
-  "Leave (and return) the point at the beginning of the current ESS function."
+(defun ess-beginning-of-function (&optional no-error)
+  "Leave (and return) the point at the beginning of the current ESS function.
+If the optional argument NO-ERROR is non-nil, the function returns nil when
+it cannot find a function beginning."
   (interactive)
   (let ((init-point (point))
 	(in-set-S4 nil)
 	beg end done)
 
+
     ;; Note that we must be sure that we are past the 'function (' text,
     ;; such that ess-function-pattern is found in BACKwards later.
     ;; In case we're sitting in a function or setMethod() header,
@@ -487,13 +504,16 @@ indentation style. At present, predefined style are `BSD', `GNU', `K&R', `C++',
 	(forward-char 1))
 
     (setq end (point)); = init-point when nothing found
+
     (ess-write-to-dribble-buffer
      (format "ess-BEG-of-fun after 'search-FWD (': Ini-pt %d, (p)-Ini-pt = %d\n"
 	     init-point (- end init-point)))
-    (if (re-search-backward ;; in case of setMethod() etc ..
-	 ess-set-function-start
-	 ;; at most one line earlier {2 is too much: finds previous sometimes}
-	 (+ 1 (ess-line-end-position -1)) t)
+    (if (and (> end 1)
+	     (re-search-backward ;; in case of setMethod() etc ..
+	      ess-set-function-start
+	      ;; at most 1 line earlier {2 is too much: finds previous sometimes}
+	      (+ 1 (ess-line-end-position -1)) t))
+
 	(progn ;; yes we *have* an S4  setMethod(..)-like
 	  (setq in-set-S4 t
 		beg (point))
@@ -518,46 +538,54 @@ indentation style. At present, predefined style are `BSD', `GNU', `K&R', `C++',
     (while (not done)
       ;; Need this while loop to skip over local function definitions
 
-      ;; In the case of non-success, it is inefficient;
+      ;; In the case of non-success, it is inefficiently
       ;; going back in the buffer through all function definitions...
-      (if (re-search-backward ess-function-pattern (point-min) t)
-	  nil
+      (unless (re-search-backward ess-function-pattern (point-min) t)
 	(goto-char init-point)
-	(error "Point is not in a function according to 'ess-function-pattern'."))
-      (setq beg (point))
-      (ess-write-to-dribble-buffer
-       (format "\tMatch,Pt:(%d,%d),%d\n" (match-beginning 0)(match-end 0) beg))
-      (setq in-set-S4 (looking-at ess-set-function-start))
-      (forward-list 1)			; get over arguments
+	(if no-error
+	    (setq  done t  beg nil)
+	  ;; else [default]:
+	  (error "Point is not in a function according to 'ess-function-pattern'.")
+	  ))
+      (unless done
+	(setq beg (point))
+	(ess-write-to-dribble-buffer
+	 (format "\tMatch,Pt:(%d,%d),%d\n"
+		 (match-beginning 0) (match-end 0) beg))
+	(setq in-set-S4 (looking-at ess-set-function-start))
+	(forward-list 1)		; get over arguments
 
-      ;; The following used to bomb  "Unbalanced parentheses", n1, n2
-      ;; when the above (search-forward "(" ..) wasn't delimited :
-      (unless in-set-S4 (forward-sexp 1))		; move over braces
-      ;;DBG (ess-write-to-dribble-buffer "|")
-      (setq end (point))
-      (goto-char beg)
-      ;; current function must begin and end around point
-      (setq done (and (>= end init-point) (<= beg init-point))))
+	;; The following used to bomb  "Unbalanced parentheses", n1, n2
+	;; when the above (search-forward "(" ..) wasn't delimited :
+	(unless in-set-S4 (forward-sexp 1)) ; move over braces
+	;;DBG (ess-write-to-dribble-buffer "|")
+	(setq end (point))
+	(goto-char beg)
+	;; current function must begin and end around point
+	(setq done (and (>= end init-point) (<= beg init-point)))))
     beg))
 
-(defun ess-end-of-function (&optional beginning)
+(defun ess-end-of-function (&optional beginning no-error)
   "Leave the point at the end of the current ESS function.
 Optional argument for location of beginning.  Return '(beg end)."
   (interactive)
   (if beginning
       (goto-char beginning)
-    (setq beginning (ess-beginning-of-function)))
-  ;; *hack* only for S (R || S+): are we in setMethod(..) etc?
-  (let ((in-set-S4 (looking-at ess-set-function-start)))
-    (ess-write-to-dribble-buffer
-     (format "ess-END-of-fun: S4=%s, beginning = %d\n" in-set-S4 beginning))
-    (forward-list 1)		; get over arguments || whole set*(..)
-    (unless in-set-S4 (forward-sexp 1))		; move over braces
-    ;;DBG (ess-write-to-dribble-buffer "ess-END-of-fun: found ok\n")
-    (list beginning (point))
-    ))
+    (setq beginning (ess-beginning-of-function no-error)))
+  (if beginning
+      ;; *hack* only for S (R || S+): are we in setMethod(..) etc?
+      (let ((in-set-S4 (looking-at ess-set-function-start)))
+	(ess-write-to-dribble-buffer
+	 (format "ess-END-of-fun: S4=%s, beginning = %d\n" in-set-S4 beginning))
+	(forward-list 1)	; get over arguments || whole set*(..)
+	(unless in-set-S4 (forward-sexp 1)) ; move over braces
+	;;DBG (ess-write-to-dribble-buffer "ess-END-of-fun: found ok\n")
+	(list beginning (point))
+	)
+    ;; else: 'no-error': we are not in a function
+    nil))
 
-;;; Kurt's version, suggested 970306.
+;;; Kurt's version, suggested 1997-03-06.
 (defun ess-mark-function ()
   "Put mark at end of ESS function, point at beginning."
   (interactive)
@@ -661,7 +689,9 @@ With prefix argument, only shows the errors ESS reported."
 	   t)
 	  (let* ((filename (buffer-substring (match-beginning 3) (match-end 3)))
 		 (fbuffer (get-file-buffer filename))
-		 (linenum (string-to-int (buffer-substring (match-beginning 2) (match-end 2))))
+		 (linenum
+		  (string-to-number
+		   (buffer-substring (match-beginning 2) (match-end 2))))
 		 (errmess (buffer-substring (match-beginning 1) (match-end 1))))
 	    (if showerr
 		  (ess-display-temp-buffer errbuff)
@@ -1154,9 +1184,11 @@ prefix argument is given, a dump() command is sent to the ESS process to
 generate the source buffer."
   (interactive
    (progn
-     (require 'ess-inf)
      (ess-force-buffer-current "Process to dump from: ")
-     (ess-read-object-name "Object to edit: ")))
+     (if (ess-ddeclient-p)
+	 (list (read-string "Object to edit: "))
+       (ess-read-object-name "Object to edit: "))))
+
   (let* ((dirname (file-name-as-directory
 		   (if (stringp ess-source-directory)
 		       ess-source-directory
@@ -1171,7 +1203,7 @@ generate the source buffer."
 
     ;; If the directory doesn't exist, offer to create it
     (if (file-exists-p (directory-file-name dirname)) nil
-      (if (y-or-n-p	; Approved
+      (if (y-or-n-p			; Approved
 	   (format "Directory %s does not exist. Create it? " dirname))
 	  (make-directory (directory-file-name dirname))
 	(error "Directory %s does not exist." dirname)))
@@ -1203,37 +1235,42 @@ generate the source buffer."
     (if (file-writable-p filename) nil
       (error "Can't dump %s as %f is not writeable." object filename))
 
-    ;; Make sure we start fresh
-    (if (get-file-buffer filename)
-	(or (kill-buffer (get-file-buffer filename))
-	    (error "Aborted.")))
+    (if (ess-ddeclient-p)
+	;; ddeclient version
+	(ess-dump-object-ddeclient object filename)
 
-    (ess-command complete-dump-command)
-    (message "Dumped in %s" filename)
+      ;; else: "normal", non-DDE behavior:
 
-    (ess-find-dump-file-other-window filename)
+      ;; Make sure we start fresh
+      (if (get-file-buffer filename)
+	  (kill-buffer (get-file-buffer filename)))
 
-    ;; PD, 1Apr97
-    ;;This ensures that the object gets indented according to ess-mode,
-    ;;not as the R/S deparser does it. At the same time, it gets rid
-    ;;of the mess generated by sending TAB characters to the readline
-    ;;functions in R when you eval-buffer-*.
-    (indent-region (point-min-marker) (point-max-marker) nil)
-    (set-buffer-modified-p nil); no need to safe just because of indenting
+      (ess-command complete-dump-command)
+      (message "Dumped in %s" filename)
 
-    ;; Don't make backups for temporary files; it only causes clutter.
-    ;; The ESS object itself is a kind of backup, anyway.
-    (unless ess-keep-dump-files
-      (make-local-variable 'make-backup-files)
-      (setq make-backup-files nil))
+      (ess-find-dump-file-other-window filename)
 
-    ;; Don't get confirmation to delete dumped files when loading
-    (if (eq ess-keep-dump-files 'check)
-	(setq ess-keep-dump-files nil))
+      ;; PD, 1Apr97
+      ;;This ensures that the object gets indented according to ess-mode,
+      ;;not as the R/S deparser does it. At the same time, it gets rid
+      ;;of the mess generated by sending TAB characters to the readline
+      ;;functions in R when you eval-buffer-*.
+      (indent-region (point-min-marker) (point-max-marker) nil)
+      (set-buffer-modified-p nil) ; no need to safe just because of indenting
 
-    ;; Delete the file if necessary
-    (if ess-delete-dump-files
-	(delete-file (buffer-file-name)))))
+      ;; Don't make backups for temporary files; it only causes clutter.
+      ;; The ESS object itself is a kind of backup, anyway.
+      (unless ess-keep-dump-files
+	(make-local-variable 'make-backup-files)
+	(setq make-backup-files nil))
+
+      ;; Don't get confirmation to delete dumped files when loading
+      (if (eq ess-keep-dump-files 'check)
+	  (setq ess-keep-dump-files nil))
+
+      ;; Delete the file if necessary
+      (if ess-delete-dump-files
+	  (delete-file (buffer-file-name))))))
 
 (defun ess-find-dump-file-other-window (filename)
   "Find ESS source file FILENAME in another window."
