@@ -1,7 +1,7 @@
 ;;; ess-site.el --- user customization of ESS
 
 ;; Copyright (C) 1993 David M. Smith
-;; Copyright (C) 1997--2005 A.J. Rossini, Rich M. Heiberger, Martin
+;; Copyright (C) 1997--2006 A.J. Rossini, Rich M. Heiberger, Martin
 ;;	Maechler, Kurt Hornik, Rodney Sparapani, and Stephen Eglen.
 
 ;; Original Author: David Smith <D.M.Smith@lancaster.ac.uk>
@@ -114,23 +114,6 @@
   ;;(defvar ess-lisp-directory
   ;;(directory-file-name "/stat2/faculty/rossini/ESS/lisp"))
 
-  ;; emacs 19.28 doesn't have functions we need, therefore we provide them
-  ;; by using files from emacs 19.29
-  (if (and (equal emacs-major-version 19) (equal emacs-minor-version 28))
-      (progn
-	(require 'cl)			; rassoc
-	;; add-to-list taken from subr.el
-	;; we use functions not in 19.28, so include them
-	(load-file (concat ess-lisp-directory "/19.29/extras.el"))
-	(load-file (concat ess-lisp-directory "/19.29/easymenu.el"))
-;;	(if window-system  ;;  essl-sas wants these even without window-system
-	    (progn
-	      ;; comment and reference faces
-	      (load-file (concat ess-lisp-directory
-				 "/19.29/faces.el"))
-	      ;; font-lock features not in 19.28
-	      (load-file (concat ess-lisp-directory
-				 "/19.29/font-lock.el")))))
 ;;)
 
   ;; emacs 19.28 and 19.29 don't have functions we need.
@@ -307,7 +290,7 @@ between .s or .S files and assembly mode.
 ;;(setq-default inferior-S4-program-name "/disk05/s4/S")
 ;;(setq-default inferior-S+4-program-name "Splus")
 ;;(setq-default inferior-S+5-program-name "Splus5")
-;;(setq-default inferior-S+6-program-name "Splus6")
+;;(setq-default inferior-S+6-program-name "Splus7") ; unix systems
 ;;(setq-default inferior-R-program-name "R")	  ; unix systems
 ;;(setq-default inferior-R-program-name "Rterm")  ; msdos systems
 ;;(setq-default inferior-R-program-name "C:\\Program Files\\R\rw1081\\bin\\Rterm.exe")	; msdos systems
@@ -346,7 +329,8 @@ between .s or .S files and assembly mode.
 
 ;;; These commands are for running the PC version of Sqpe of S+4 and
 ;;; S+6 in an emacs buffer, using the same technology as ESS uses for
-;;; Unix S-Plus.  Interactive graphics are unavailable in this mode.
+;;; Unix S-Plus.  Interactive graphics with javagraph are available
+;;; in this mode beginning with S-Plus 6.1.
 ;;; See essd-sp4.el or essd-sp6w.el
 
 ;;; These are the defaults.  Change them here if the defaults don't work.
@@ -357,9 +341,9 @@ between .s or .S files and assembly mode.
 ;;(setq-default inferior-Sqpe+4-SHOME-name "c:/progra~1/SPLS45SE")
 ;;(setq-default inferior-Sqpe+4-program-name "c:/progra~1/SPLS45SE/cmd/Sqpe.exe")
 ;;
-;;(setq-default inferior-S+6-program-name "c:/progra~1/Insightful/SPLUS6/cmd/Splus")
-;;(setq-default inferior-Sqpe+6-SHOME-name "c:/progra~1/Insightful/SPLUS6")
-;;(setq-default inferior-Sqpe+6-program-name "c:/progra~1/Insightful/SPLUS6/cmd/Sqpe.exe")
+;;(setq-default inferior-S+6-program-name "c:/progra~1/Insightful/splus70/cmd/Splus")
+;;(setq-default inferior-Sqpe+6-SHOME-name "c:/progra~1/Insightful/splus70")
+;;(setq-default inferior-Sqpe+6-program-name "c:/progra~1/Insightful/splus70/cmd/Sqpe.exe")
 
 ;;; These ddeclient values will be buffer-local on MS-Windows 9x/NT
 (setq-default inferior-ess-ddeclient	     "Initial")
@@ -568,6 +552,11 @@ sending `inferior-ess-language-start' to S-Plus.")
 ;;; process.  To number all processes, uncomment the next line.
 ;;(setq ess-plain-first-buffername nil)
 
+;;; (3.02) Some people have requested using the program name as part
+;;; of the buffer.  Turned on for R.
+;;(setq ess-use-inferior-program-name-in-buffer-name t)
+
+
 ;;; (3.1) Font-lock
 ;; The following two expressions automatically enable font-lock-mode
 ;; for ess-mode and inferior-ess-mode buffers.
