@@ -397,8 +397,9 @@ name and path, if it exists, anywhere in the sub-tree."
     ess-tmp-return))
 
 (defun ess-find-exec-completions (ess-root-arg &optional ess-exec-dir)
-"Given the root of an executable file name, find all possible completions,
-if any exist, in PATH."
+  "Given the root of an executable file name, find all possible completions.
+Search for the executables in ESS-EXEC-DIR which defaults to
+`exec-path' if no value is given."
   (let* ((ess-exec-path
 	 (if ess-exec-dir (ess-return-list ess-exec-dir) exec-path))
 	(ess-tmp-exec nil)
@@ -623,4 +624,29 @@ we simply do not break it (instead of breaking after the first word)."
       (justify-current-line justify t t)
       t)))
 
+(defun ess-select-frame-set-input-focus (frame)
+  "Select FRAME, raise it, and set input focus, if possible.
+Copied almost verbatim from gnus-utils.el (but with test for mac added)."
+  (cond ((featurep 'xemacs)
+	 (raise-frame frame)
+	 (select-frame frame)
+	 (focus-frame frame))
+	;; The function `select-frame-set-input-focus' won't set
+	;; the input focus under Emacs 21.2 and X window system.
+	;;((fboundp 'select-frame-set-input-focus)
+	;; (defalias 'gnus-select-frame-set-input-focus
+	;;   'select-frame-set-input-focus)
+	;; (select-frame-set-input-focus frame))
+	(t
+	 (raise-frame frame)
+	 (select-frame frame)
+	 (cond ((and 
+		 (memq window-system '(x mac))
+		 (fboundp 'x-focus-frame))
+		(x-focus-frame frame))
+	       ((eq window-system 'w32)
+		(w32-focus-frame frame)))
+	 (when focus-follows-mouse
+	   (set-mouse-position frame (1- (frame-width frame)) 0)))))
+
 (provide 'ess-utils)
