@@ -630,7 +630,24 @@ current buffer if nil."
 
 	      (if ess-sas-temp-buff (switch-to-buffer ess-sas-temp-buff)
 	        ;; else
-		(if no-create (setq revert nil) (find-file ess-sas-temp-file)))
+		(if no-create (setq revert nil) 
+		    (if (file-exists-p ess-sas-temp-file)
+			(find-file ess-sas-temp-file))))
+		    ;; else
+		    ;;	(let* ((ess-sas-buffer-list (buffer-list)) 
+		    ;;	       (ess-sas-buffer-list-index 0)
+		    ;;	       (ess-sas-buffer-list-file nil)
+		    ;;	       (ess-sas-buffer-list-length (length ess-sas-buffer-list)))
+		    ;;	    (while (< ess-sas-buffer-list-index ess-sas-buffer-list-length)
+		    ;;		(setq ess-sas-buffer-list-file 
+		    ;;		    (buffer-file-name (nth ess-sas-buffer-list-index ess-sas-buffer-list)))
+		    ;;		(if (and ess-sas-buffer-list-file
+		    ;;		    (string-match (concat "." suffix) ess-sas-buffer-list-file))
+		    ;;		    (switch-to-buffer (nth ess-sas-buffer-list-index ess-sas-buffer-list))
+		    ;;		    (setq ess-sas-buffer-list-index ess-sas-buffer-list-length)
+		    ;;		)
+		    ;;		(setq ess-sas-buffer-list-index (+ 1 ess-sas-buffer-list-index))
+		    ;;    )))
 
 	      (if (and (not no-create)
 		       (or (string-equal suffix "log")
@@ -683,15 +700,17 @@ current buffer if nil."
 
   (let ((ess-sas-error (concat
     "^ERROR [0-9]+-[0-9]+:\\|^ERROR:\\|_ERROR_=1 _N_=\\|_ERROR_=1[ ]?$"
-    "\\|NOTE: MERGE statement has more than one data set with repeats of BY values."
+    "\\|NOTE: MERGE statement has more than one data set with repeats"
     "\\|NOTE: Variable .* is uninitialized."
+    "\\|NOTE: SAS went to a new line when INPUT statement reached past" 
+    "\\|NOTE 485-185: Informat .* was not found"
+    "\\|NOTE: Estimated G matrix is not positive definite."
+    "\\|NOTE: Compressing data set .* increased size by"
     "\\|WARNING: Apparent symbolic reference .* not resolved."
-    "\\|NOTE 485-185: Informat .* was not found or could not be loaded."
     "\\|WARNING: Length of character variable has already been set."
     "\\|WARNING: Not all variables in the list "
     "\\|WARNING: RUN statement ignored due to previous errors."
-    "\\|Bus Error In Task\\|Segmentation Violation In Task"
-    "\\|NOTE: Estimated G matrix is not positive definite."))
+    "\\|Bus Error In Task\\|Segmentation Violation In Task"))
 	(ess-sas-save-point nil) (ess-sas-pop-mark nil))
 
   (if (ess-sas-goto "log" 'revert) (progn
