@@ -65,14 +65,15 @@
      (ess-cmd-delay			. ess-R-cmd-delay)
      (ess-function-pattern              . ess-R-function-pattern)
      (ess-object-name-db-file		. "ess-r-namedb.el" )
-     (ess-retr-lastvalue-command	. "assign(\".Last.value\", .ess.lvsave, envir=NULL)\n") ; package:base
-     (ess-save-lastvalue-command	. "assign(\".ess.lvsave\",.Last.value,inherits=TRUE)\n") ;envir=1
+     (ess-retr-lastvalue-command	. "assign(\".Last.value\", .ess.lvsave, envir=baseenv())\n")
+     (ess-save-lastvalue-command	. "assign(\".ess.lvsave\", get(\".Last.value\", envir=baseenv()))\n")
      (ess-imenu-mode-function		. 'ess-imenu-R)
      (inferior-ess-program		. inferior-R-program-name)
      (inferior-ess-objects-command	. inferior-R-objects-command)
      (inferior-ess-font-lock-keywords   . inferior-ess-R-font-lock-keywords)
      (inferior-ess-search-list-command	. "search()\n")
      (inferior-ess-help-command		. "help(\"%s\", htmlhelp=FALSE)\n")
+     (inferior-ess-help-filetype        . nil)
      (inferior-ess-exit-command		. "q()")
      (inferior-ess-exit-prompt		. "Save workspace image? [y/n/c]: ")
      (inferior-ess-primary-prompt	. "\\([A-Z][][A-Za-z0-9.]*\\)*> ")
@@ -98,6 +99,7 @@ version of R.
 If duplicate versions of the same program are found (which happens if
 the same path is listed on `exec-path' more than once), they are
 ignored by calling `ess-uniq-list'.
+Set this variable to nil to disable searching for other versions of R.
 If you set this variable, you need to restart Emacs (and set this variable
 before ess-site is loaded) for it to take effect.")
 
@@ -115,7 +117,7 @@ to R, put them in the variable `inferior-R-args'."
     "\n(R): ess-dialect=%s, buf=%s, start-arg=%s\n current-prefix-arg=%s\n"
     ess-dialect (current-buffer) start-args current-prefix-arg))
   (let* ((r-always-arg
-	  (if ess-microsoft-p
+	  (if (or ess-microsoft-p (eq system-type 'cygwin))
 	      "--ess "
 	    "--no-readline "))
 	 (r-start-args
@@ -135,6 +137,9 @@ to R, put them in the variable `inferior-R-args'."
     (ess-write-to-dribble-buffer
      (format "(R): inferior-ess-language-start=%s\n"
 	     inferior-ess-language-start))
+    ;; currently rely on baseenv() which is in R only since version 2.2:
+    (ess-eval-linewise
+     "if(!exists(\"baseenv\", mode=\"function\")) baseenv <- function() NULL")
     (if inferior-ess-language-start
 	(ess-eval-linewise inferior-ess-language-start))))
 
@@ -167,18 +172,21 @@ The local variable `ess-r-versions-created' is used to return list of
 the new R defuns, if any, that were created.  The defuns will normally
 be placed on the menubar upon ESS initialisation."
 
-  ;; This works by creating a temp buffer where the template function is
-  ;; edited so that X.Y is replaced by the version name
-  (let ((template "")
-	(beg)
-	(versions)
-	(version)
-	(eval-buf (get-buffer-create "*ess-temp-r-evals*"))
-	(ess-r-versions-created)
-	)
-    ;;
-    ;; This is the template function used for creating M-x R-X.Y.
-    (setq template "(defun R-X.Y (&optional start-args)
+
+  (if (not ess-r-versions)
+      nil				;nothing to return
+    ;; else, if ess-r-versions is non-nil, let's try to find those R versions.
+    ;; This works by creating a temp buffer where the template function is
+    ;; edited so that X.Y is replaced by the version name
+    (let ((template "")
+	  (beg)
+	  (versions)
+	  (version)
+	  (eval-buf (get-buffer-create "*ess-temp-r-evals*"))
+	  (ess-r-versions-created)
+	  )
+      ;; This is the template function used for creating M-x R-X.Y.
+      (setq template "(defun R-X.Y (&optional start-args)
   \"Call R-X.Y, i.e., the R version 'R-X.Y' using ESS.
 This function was generated by `ess-r-versions-create'.\"
   (interactive \"P\")
@@ -186,45 +194,46 @@ This function was generated by `ess-r-versions-create'.\"
     (R start-args)))
 
 ")
-    (save-excursion
-      (set-buffer eval-buf)
-      ;; clear the buffer.
-      (delete-region (point-min) (point-max))
-
-      ;; Find which versions of R we want.  Remove the pathname, leaving just
-      ;; the name of the executable.
-      (setq versions
-	    (ess-uniq-list
-	     (mapcar 'file-name-nondirectory
-		     (apply 'nconc
-			    (mapcar 'ess-find-exec-completions
-				    ess-r-versions)))))
-      (ess-write-to-dribble-buffer
-       (format "(R): ess-r-versions-create making M-x defuns for %s"
-	       (mapconcat 'identity versions " ")))
-      (setq ess-r-versions-created versions) ;keep copy for returning at end.
-      ;; Iterate over each string in VERSIONS, creating a new defun each time.
-      (while versions
-	(setq version (car versions)
-	      versions (cdr versions))
-	(setq beg (point))
-	(insert template)
-	(goto-char beg)
-	(while (search-forward "R-X.Y" nil t)
-	  (replace-match version t t))
-	(goto-char (point-max))
+      (save-excursion
+	(set-buffer eval-buf)
+	;; clear the buffer.
+	(delete-region (point-min) (point-max))
+	
+	;; Find which versions of R we want.  Remove the pathname, leaving just
+	;; the name of the executable.
+	(setq versions
+	      (ess-uniq-list
+	       (mapcar 'file-name-nondirectory
+		       (apply 'nconc
+			      (mapcar 'ess-find-exec-completions
+				      ess-r-versions)))))
+	(ess-write-to-dribble-buffer
+	 (format "(R): ess-r-versions-create making M-x defuns for %s"
+		 (mapconcat 'identity versions " ")))
+	(setq ess-r-versions-created versions) ;keep copy for returning at end.
+	;; Iterate over each string in VERSIONS, creating a new defun each time.
+	(while versions
+	  (setq version (car versions)
+		versions (cdr versions))
+	  (setq beg (point))
+	  (insert template)
+	  (goto-char beg)
+	  (while (search-forward "R-X.Y" nil t)
+	    (replace-match version t t))
+	  (goto-char (point-max))
+	  )
+	;; buffer has now been created with defuns, so eval them!
+	(eval-buffer)
+	(kill-buffer eval-buf)
 	)
-      ;; buffer has now been created with defuns, so eval them!
-      (eval-buffer)
-      (kill-buffer eval-buf)
-      )
-    ess-r-versions-created))
+      ess-r-versions-created)))
 
 
 (defun ess-find-rterm (&optional ess-R-root-dir)
   "Find the full path of all occurences of Rterm.exe under the ESS-R-ROOT-DIR.
 If ESS-R-ROOT-DIR is nil, construct it by looking for an occurence of Rterm.exe
-in the exec-path."
+in the exec-path.  If there are no occurences of Rterm.exe in the exec-path,
+then use \"c:/progra~1/R\" which is the default location for the R distribution."
   (let* ((Rpath)
 	 (rwxxyy)
 	 (rw)
@@ -238,8 +247,13 @@ in the exec-path."
 		     (concat
 		      (file-name-directory Rpath)
 		      "../../"))
-		  ""))))
-    (setq rwxxyy (file-name-all-completions "rw" ess-R-root-dir))
+		  "c:/progra~1/R"))))
+    (setq rwxxyy (append (file-name-all-completions "rw" ess-R-root-dir)
+			 (file-name-all-completions "R-1" ess-R-root-dir)
+			 (file-name-all-completions "R-2" ess-R-root-dir)
+			 (file-name-all-completions "R-devel" ess-R-root-dir)
+			 (file-name-all-completions "R-patched" ess-R-root-dir)
+))  ;; this needs to rewritten to use (append '("rw") ess-r-versions)
     (while rwxxyy
       (setq rw (car rwxxyy))
       (setq rwxxyy (cdr rwxxyy))
@@ -261,6 +275,7 @@ placed on the menubar upon ESS initialisation."
 	(beg)
 	(versions)
 	(version)
+	(version-root)
 	(eval-buf (get-buffer-create "*ess-temp-r-evals*"))
 	(ess-rterm-versions-created)
 )
