@@ -117,7 +117,7 @@ Better logic needed!  (see 2 uses, in this file).")
       (accept-process-output (get-buffer-process (current-buffer)))
       (sleep-for 2) ; need to wait, else working too fast!
       (setq ess-sas-log (ess-insert-accept "tty"))
-      (SAS-log-mode)
+      ;(SAS-log-mode)
       (shell-mode)
       (ess-transcript-minor-mode t)
       (rename-buffer ess-sas-log-bufname t))
@@ -185,6 +185,7 @@ Better logic needed!  (see 2 uses, in this file).")
     (comint-use-prompt-regexp-instead-of-fields . t) ;; emacs 21 and up
     (inferior-ess-start-file       . nil) ;"~/.ess-SAS")
     (inferior-ess-start-args       . inferior-SAS-args-temp)
+    (inferior-ess-font-lock-keywords . SAS-mode-font-lock-keywords)
     ;; (ess-pre-run-hook              . 'ess-SAS-pre-run-hook)
     (ess-local-process-name        . nil))
   "Variables to customize for SAS")
@@ -211,11 +212,22 @@ Better logic needed!  (see 2 uses, in this file).")
   (define-key sas-mode-local-map "\C-ci" 'ess-eval-line-and-step-invisibly)
   (define-key sas-mode-local-map ";" 'ess-electric-run-semicolon)
 
-  (define-key sas-mode-local-map "\C-c\C-p" 'ess-sas-file-path)
-  (define-key sas-mode-local-map "\C-c\C-b" 'ess-sas-submit)
-  (define-key sas-mode-local-map "\C-c\C-r" 'ess-sas-submit-region)
-  (define-key sas-mode-local-map "\C-c\C-x" 'ess-sas-goto-log)
-  (define-key sas-mode-local-map "\C-c\C-y" 'ess-sas-goto-lst)
+; this is a mess
+; interactive and batch commands share sas-mode-local-map,
+; but the associated commands are very different
+; what would be better is two maps like
+; sas-batch-mode-local-map and sas-interactive-mode-local-map
+; or smart function definitions that would do the appropriate
+; thing for either batch or interactive sessions
+; however, neither of these solutions are planned
+; therefore, no key definitions can be shared between
+; batch and interactive at this time, hence the lines that
+; are commented below:  uncomment at your own risk
+;  (define-key sas-mode-local-map "\C-c\C-p" 'ess-sas-file-path)
+;  (define-key sas-mode-local-map "\C-c\C-b" 'ess-sas-submit)
+;  (define-key sas-mode-local-map "\C-c\C-r" 'ess-sas-submit-region)
+;  (define-key sas-mode-local-map "\C-c\C-x" 'ess-sas-goto-log)
+;  (define-key sas-mode-local-map "\C-c\C-y" 'ess-sas-goto-lst)
 
   (use-local-map sas-mode-local-map))
 
@@ -223,7 +235,7 @@ Better logic needed!  (see 2 uses, in this file).")
 (defun ess-electric-run-semicolon (arg)
   "Insert character.  If the line contains \"run;\" and nothing else then indent line."
   (interactive "P")
-  (let (insertpos)
+  (if ess-sas-edit-keys-toggle (insert ";") (let (insertpos)
     (if (and (not arg)
 	     (eolp)
 	     (save-excursion
@@ -231,11 +243,7 @@ Better logic needed!  (see 2 uses, in this file).")
 		   (backward-word 1)
 		   (and (looking-at "run")
 			(progn
-			;; if ess-sas-edit-keys-toggle, then
-			;; call ess-sas-backward-delete-tab
-			;; rather than skip-chars-backward
-			  (if ess-sas-edit-keys-toggle (ess-sas-backward-delete-tab)
-			      (skip-chars-backward " \t"))
+			      (skip-chars-backward " \t")
 			  (bolp)))))
 	(progn
 	  (insert last-command-char)
@@ -247,7 +255,7 @@ Better logic needed!  (see 2 uses, in this file).")
 	(save-excursion
 	  (goto-char insertpos)
 	  (self-insert-command (prefix-numeric-value arg)))
-      (self-insert-command (prefix-numeric-value arg)))))
+      (self-insert-command (prefix-numeric-value arg))))))
 
 (defun SAS ()
   "Call 'SAS', from SAS Institute."
