@@ -48,6 +48,7 @@
      (ess-object-name-db-file       	. "ess-s+3-namedb.el" )
      (inferior-ess-program          	. inferior-S+3-program-name)
      (inferior-ess-help-command     	. "help(\"%s\",pager=\"cat\",window=F)\n")
+     (inferior-ess-help-filetype . nil)
      (inferior-ess-search-list-command  . "search()\n")
      (inferior-ess-start-file       	. nil) ;"~/.ess-S+3")
      (inferior-ess-start-args       . "")
@@ -73,7 +74,7 @@
   (interactive)
   (setq ess-customize-alist S+3-customize-alist)
   (ess-mode S+3-customize-alist proc-name)
-  (if ess-S-use-imenu (ess-imenu-R)))
+  (if ess-imenu-use-S (ess-imenu-S)))
 
 (defun S+3-transcript-mode ()
   "S-PLUS 3.x transcript mode."
