@@ -1,4 +1,4 @@
-;;; essd-sp6.el --- S-Plus 6 & 7  customization
+;;; essd-sp6.el --- S-Plus 6 & 7 & 8  customization
 
 ;; Copyright (C) 2001--2005 A.J. Rossini, Rich M. Heiberger, Martin
 ;;	Maechler, Kurt Hornik, Rodney Sparapani, and Stephen Eglen.
@@ -82,6 +82,7 @@
      (ess-object-name-db-file		. "ess-sp6-namedb.el")
      (inferior-ess-program		. inferior-S+6-program-name)
      (inferior-ess-help-command	  . "help(\"%s\",pager=\"slynx -dump\",window=F)\n")
+     (inferior-ess-help-filetype . nil)
      (inferior-ess-search-list-command	. "searchPaths()\n")
 
      (ess-directory-function		. S+6-directory-function)
@@ -141,6 +142,8 @@ version of S.
 If duplicate versions of the same program are found (which happens if
 the same path is listed on `exec-path' more than once), they are
 ignored by calling `ess-uniq-list'.
+Set this variable to nil to disable searching for other versions
+of S using this method.  
 If you set this variable, you need to restart Emacs (and set this variable
 before ess-site is loaded) for it to take effect.
 
@@ -184,30 +187,30 @@ This function was generated by `ess-s-versions-create'.\"
       ;; clear the buffer.
       (delete-region (point-min) (point-max))
 
-      ;; Find which versions of S we want.  Remove the pathname, leaving just
-      ;; the name of the executable.
-      (setq versions
-	    (ess-uniq-list
-	     (mapcar 'file-name-nondirectory
-		     (apply 'nconc
-			    (mapcar 'ess-find-exec-completions
-				    ess-s-versions)))))
-      (ess-write-to-dribble-buffer
-       (format "(S): ess-s-versions-create making M-x defuns for %s"
-	       (mapconcat 'identity versions " ")))
-      (setq ess-s-versions-created versions) ;keep copy for returning at end.
-      ;; Iterate over each string in VERSIONS, creating a new defun each time.
-      (while versions
-	(setq version (car versions)
-	      versions (cdr versions))
-	(setq beg (point))
-	(insert template)
-	(goto-char beg)
-	(while (search-forward "S-X.Y" nil t)
-	  (replace-match version t t))
-	(goto-char (point-max))
-	)
-
+      (when ess-s-versions
+	;; Find which versions of S we want.  Remove the pathname, leaving just
+	;; the name of the executable.
+	(setq versions
+	      (ess-uniq-list
+	       (mapcar 'file-name-nondirectory
+		       (apply 'nconc
+			      (mapcar 'ess-find-exec-completions
+				      ess-s-versions)))))
+	(ess-write-to-dribble-buffer
+	 (format "(S): ess-s-versions-create making M-x defuns for %s"
+		 (mapconcat 'identity versions " ")))
+	(setq ess-s-versions-created versions) ;keep copy for returning at end.
+	;; Iterate over each string in VERSIONS, creating a new defun each time.
+	(while versions
+	  (setq version (car versions)
+		versions (cdr versions))
+	  (setq beg (point))
+	  (insert template)
+	  (goto-char beg)
+	  (while (search-forward "S-X.Y" nil t)
+	    (replace-match version t t))
+	  (goto-char (point-max))
+	  ))
 
       ;; Check if we have any static defuns to evaluate.
       (when ess-s-versions-list
