@@ -36,7 +36,7 @@
 ;;; Requires and Autoloads:
 
 (require 'essl-s)
-(require 'ess-iw32)
+;;NO: this is autoloaded from other places (require 'ess-dde)
 
 (autoload 'inferior-ess "ess-inf" "Run an ESS process.")
 (autoload 'ess-mode     "ess-mode" "Edit an ESS process.")
@@ -60,7 +60,7 @@ Easily changeable in a user's `.emacs'.")
 )
 
 (defvar inferior-S+6-multipleinstances "/MULTIPLEINSTANCES"
-  "Default \"/MULTIPLEINSTANCES\" opens up a new instance of S+[67] in a
+  "Default \"/MULTIPLEINSTANCES\" opens up a new instance of S+[678] in a
 GUI window and connects it to the '(ddeESS [S+6])' window.  The
 alternative nil uses an existing S+6 GUI (if there is one) and
 connects it to the '(ddeESS [S+6])' window.")
@@ -73,6 +73,7 @@ connects it to the '(ddeESS [S+6])' window.")
     (ess-object-name-db-file    . "ess-sp6-namedb.el" )
     (inferior-ess-program       . inferior-S+6-program-name)
     (inferior-ess-help-command  . "help(\"%s\")\n")
+    (inferior-ess-help-filetype . "chm")
     (inferior-ess-search-list-command . "searchPaths()\n")
     (inferior-ess-start-file    . nil) ;"~/.ess-S+6")
     (inferior-ess-start-args    . (concat
@@ -99,6 +100,7 @@ connects it to the '(ddeESS [S+6])' window.")
     (ess-object-name-db-file    . "ess-sp6-namedb.el" )
     (inferior-ess-program       . inferior-Sqpe+6-program-name)
     (inferior-ess-help-command  . "help(\"%s\")\n")
+    (inferior-ess-help-filetype . "chm")
     (inferior-ess-search-list-command . "searchPaths()\n")
     (inferior-ess-start-file    . nil) ;"~/.ess-S+6")
     (inferior-ess-start-args    . (concat
@@ -114,7 +116,8 @@ connects it to the '(ddeESS [S+6])' window.")
 
 
 
-;;; There are extra complications in S+6 and S+7 (compared to S+3) because
+;;; There are extra complications in S+6 and S+7 and S+8 (compared to S+3)
+;;; because
 ;;;
 ;;; (1) The StatSci supplied Splus.exe doesn't work in an emacs
 ;;;     buffer.  It works as as a GUI window and we must send commands
@@ -141,10 +144,12 @@ connects it to the '(ddeESS [S+6])' window.")
 ;;;     then '(ddeESS [S+6])' becomes a shell buffer.
 ;;;
 (defun S+6 (&optional proc-name)
-  "Verify that `inferior-S+6-program-name' points to S-Plus 6 or S-Plus 7.
-Start normally for S-Plus 6.1 and later.  Inform the user to start S-Plus 6.0
-from the icon and then connect to it with `S+6-existing'.  Give an error
-message if `inferior-S+6-program-name' doesn't point to S-Plus 6 or S-Plus 7."
+  "Verify that `inferior-S+6-program-name' points to S-Plus 6 or
+S-Plus 7 or S-Plus 8.  Start normally for S-Plus 6.1 and later.
+Inform the user to start S-Plus 6.0 from the icon and then
+connect to it with `S+6-existing'.  Give an error message if
+`inferior-S+6-program-name' doesn't point to S-Plus 6 or S-Plus 7
+or S-Plus 8."
   (interactive)
   (save-excursion
     (set-buffer (find-file-noselect
@@ -152,24 +157,23 @@ message if `inferior-S+6-program-name' doesn't point to S-Plus 6 or S-Plus 7."
 			 "/../../versions") t))
     (toggle-read-only 1)
     (forward-line)
-    (if (not (search-backward-regexp "[67].[0-9]" (point-min) t))
+    (if (not (search-backward-regexp "splus\t[678].[0-9]" (point-min) t))
 	(error "The emacs variable `inferior-S+6-program-name' does
-not point to S-Plus 6 or 7.  Please add `splus[67]?/cmd'
-(expand the `[67]?' to match your setup) to your `exec-path' or
-specify the complete path to `Splus.exe' in the variable
-`inferior-S+6-program-name' in your `.emacs' file.")
-      (progn
-    (forward-line)
-      (if (search-backward "6.0" (point-min) t)
-	    (error "S-Plus 6.0 for Microsoft Windows has a bug that
+not point to S-Plus 6 or 7 or 8.  Please add `splus[678]?/cmd' (expand the
+`[678]?' to match your setup) to your `exec-path' or specify the complete
+path to `Splus.exe' in the variable `inferior-S+6-program-name' in your
+`.emacs' file.")
+      (forward-line)
+      (if (search-backward "splus\t6.0" (point-min) t)
+	  (error "S-Plus 6.0 for Microsoft Windows has a bug that
 prevents it from being started by emacs.  Instead, you must start it
 by double-clicking an icon.  Then you can connect to it with
-`S+6-existing'.  You should consider upgrading to S-Plus 6.1 or higher.")
-  (S+6-initiate proc-name))) ;; normal start ;
-      )))
+`S+6-existing'.  You should consider upgrading to S-Plus 6.1 or higher."))))
+  (S+6-initiate proc-name)) ;; normal start ;
+
 
 (defun S+6-initiate (&optional proc-name)
-  "Call 'S-PLUS [67].x for Windows', the 'GUI Thing' from StatSci.  Put
+  "Call 'S-PLUS [678].x for Windows', the 'GUI Thing' from StatSci.  Put
 S-Plus in an independent MS-Window (Splus persists even if the
 '(ddeESS [S+6])' window is killed in emacs).  Do this by creating a
 comint process that calls sh.  Send a shell command in that sh buffer
@@ -246,7 +250,7 @@ Splus Commands window appear in this buffer.\n\n")
 
 
 (defun S+6-existing (&optional proc-name)
-  "Call 'S-PLUS [67].x for Windows', the 'GUI Thing' from StatSci.  Do so by
+  "Call 'S-PLUS [678].x for Windows', the 'GUI Thing' from StatSci.  Do so by
 finding an existing S-Plus in an independent MS-Window (if there is one) and
 set up a '(ddeESS [S+6])' buffer in emacs.  If there is no existing
 S-Plus, then a new one will be opened in the default directory,
@@ -283,7 +287,7 @@ Splus Commands window blink a DOS window and you won't see them.\n\n")
 ;;;     it will provide prompts.
 ;;;
 (defun Sqpe+6 (&optional proc-name)
-  "Call 'Sqpe' from 'S-PLUS [67].x for Windows', the 'Real Thing'  from StatSci."
+  "Call 'Sqpe' from 'S-PLUS [678].x for Windows', the 'Real Thing' from StatSci."
   (interactive)
   (setq ess-customize-alist Sqpe+6-customize-alist)
   (let* ((shome-nil-p (equal (getenv "SHOME") nil)))
@@ -319,7 +323,7 @@ Splus Commands window blink a DOS window and you won't see them.\n\n")
 
 
 (defun S+6-mode (&optional proc-name)
-  "Major mode for editing S+[67] source.  See `ess-mode' for more help."
+  "Major mode for editing S+[678] source.  See `ess-mode' for more help."
   (interactive)
   (setq ess-customize-alist S+6-customize-alist)
   (ess-mode S+6-customize-alist proc-name)
@@ -333,10 +337,12 @@ Splus Commands window blink a DOS window and you won't see them.\n\n")
 
 
 (defun S+6-msdos (&optional proc-name)
-  "Verify that `inferior-S+6-program-name' points to S-Plus 6 or S-Plus 7.
-Start normally for S-Plus 6.1 and later.  Inform the user to start S-Plus 6.0
-from the icon and then connect to it with `S+6-msdos-existing'.  Give an error
-message if `inferior-S+6-program-name' doesn't point to S-Plus 6 or S-Plus 7."
+  "Verify that `inferior-S+6-program-name' points to S-Plus 6 or
+S-Plus 7 or S-Plus 8.  Start normally for S-Plus 6.1 and later.
+Inform the user to start S-Plus 6.0 from the icon and then
+connect to it with `S+6-msdos-existing'.  Give an error message
+if `inferior-S+6-program-name' doesn't point to S-Plus 6 or
+S-Plus 7 or S-Plus 8."
   (interactive)
   (save-excursion
     (set-buffer (find-file-noselect
@@ -344,15 +350,15 @@ message if `inferior-S+6-program-name' doesn't point to S-Plus 6 or S-Plus 7."
 			 "/../../versions") t))
     (toggle-read-only 1)
     (forward-line)
-    (if (not (search-backward-regexp "[67].[0-9]" (point-min) t))
+    (if (not (search-backward-regexp "splus\t[678].[0-9]" (point-min) t))
 	(error "The emacs variable `inferior-S+6-program-name' does
-not point to S-Plus 6 or 7.  Please add `splus[67]?/cmd'
-(expand the `[67]?' to match your setup) to your `exec-path' or
+not point to S-Plus 6 or 7 or 8.  Please add `splus[678]?/cmd'
+(expand the `[678]?' to match your setup) to your `exec-path' or
 specify the complete path to `Splus.exe' in the variable
 `inferior-S+6-program-name' in your `.emacs' file.")
       (progn
     (forward-line)
-      (if (search-backward "6.0" (point-min) t)
+      (if (search-backward "splus\t6.0" (point-min) t)
 	    (error "S-Plus 6.0 for Microsoft Windows has a bug that
 prevents it from being started by emacs.  Instead, you must start it
 by double-clicking an icon.  Then you can connect to it with
@@ -362,7 +368,7 @@ by double-clicking an icon.  Then you can connect to it with
 
 
 (defun S+6-msdos-initiate (&optional proc-name)
-  "Call 'S-PLUS [67].x for Windows', the 'GUI Thing' from StatSci.  Put
+  "Call 'S-PLUS [678].x for Windows', the 'GUI Thing' from StatSci.  Put
 S-Plus in an independent MS-Window (Splus persists even if the
 '(ddeESS [S+6])' window is killed in emacs).  Do this by creating a
 comint process that calls sh.  Send a shell command in that sh buffer
@@ -447,7 +453,7 @@ Splus Commands window (are supposed to) appear in this buffer.\n\n")
     ))
 
 (defun S+6-msdos-existing (&optional proc-name)
-  "Call 'S-PLUS [67].x for Windows', the 'GUI Thing' from StatSci.  Do so by
+  "Call 'S-PLUS [678].x for Windows', the 'GUI Thing' from StatSci.  Do so by
 finding an existing S-Plus in an independent MS-Window (if there is one) and
 set up a '(ddeESS [S+6])' buffer in emacs.  If there is no existing
 S-Plus, then a new one will be opened in the default directory,
