@@ -246,6 +246,9 @@ Placeholders (substituted `at runtime'): $A$ for `Author', $D$ for `Date'.")
   (if (file-exists-p outline-file)
       (setq ess-function-outline-file outline-file)))
 
+(defvar ess-S-assign-key "_"
+  "This key will be mapped to insert ess-S-assign '<-'")
+
  ; Function Definitions
 
 (defun S-comment-indent ()
@@ -453,7 +456,7 @@ Uses the file given by the variable `ess-function-outline-file'."
 (defun ess-dump-to-src (&optional dont-query verbose)
   "Make the changes in an S - dump() file to improve human readability."
   (interactive "P")
-  (ess-replace-regexp-dump-to-src  "^\"\\([a-z.][a-z.0-9]*\\)\"<-\n"
+  (ess-replace-regexp-dump-to-src  "^\"\\([a-z.][a-z.0-9]*\\)\" *<-\n"
 				   "\n\\1 <- "
 				   dont-query verbose 'ensure-ess))
 
@@ -520,7 +523,7 @@ nil (as by default) !"
     (ess-replace-regexp-dump-to-src ;; all those *not* ending in ","
      ;; including  Mat[ i, ] = ...,
      ;; but not `names(x) = "..."' for that is "confused" with plot(x=x,..)
-     "^\\( *[a-z.][][, \"_a-z.0-9]*\\) *= *\\([a-z.0-9({].*[^,] *$\\)"
+     "^\\( *[a-z.][][, \"_a-z.0-9]*\\) *= *\\([a-z.0-9({]\\(.*[^,]\\)? *$\\)"
      "\\1 <- \\2" nil ;; always query - often has many "false positives"
      verbose)
     ))
@@ -528,7 +531,7 @@ nil (as by default) !"
 ;;; All of the above three :
 (defun ess-MM-fix-src (&optional dont-query verbose)
   "Clean up ess-source code which has been produced by dump(..), and other
-code not typically produced by other tools.  Produces more readable code,
+code typically produced by other tools.  Produces more readable code,
 and one that is well formatted in emacs ess-mode."
   (interactive "P")
   ;; each of the following does a save-excursion:
@@ -550,6 +553,10 @@ and one that is well formatted in emacs ess-mode."
 	 (require 'essd-r)
 	 (R-fix-T-F from (not verbose))))
 
+    ;; former C and matlab programmers leave trailing  ";" :
+    (goto-char from) (ess-rep-regexp "; *$" "" nil 'literal verbose)
+    (goto-char from) (ess-rep-regexp ";\\( *\\)#" "\\1#" nil 'literal verbose)
+
     ;;from R 1.9.x "_" is valid in names; here assume no initial / trailing '_'
     (goto-char from) (ess-rep-regexp " +_ *" " <- " nil 'literal verbose)
     (goto-char from) (ess-rep-regexp   "_ +" " <- " nil 'literal verbose)
@@ -587,6 +594,30 @@ and one that is well formatted in emacs ess-mode."
 		     "\\1\n}" 'fix nil verbose)
     ))
 
+;; This is by Seth Falcon, modeled after ess-toggle-underscore (see below).
+;; FIXME:  "toggle" should revert to previous behavior, i.e. by default to
+;; -----   smart underscore
+(defun ess-toggle-S-assign-key (force)
+  "Set the key defined in `ess-S-assign-key'"
+  (interactive "P")
+  (require 'ess-mode)
+  (require 'ess-inf)
+  (let ((current-key (lookup-key ess-mode-map ess-S-assign-key))
+	(insert-S-assign #'(lambda() (interactive)
+			     (delete-horizontal-space) (insert ess-S-assign))))
+    (message "[ess-toggle-S-assign-key:] current-key is '%s'" current-key)
+    (if current-key
+	(setq ess-S-previous-assign-key current-key))
+    (if (and current-key
+	     ;; (stringp current-key) (string= current-key ess-S-assign)
+	     (not force))
+	(progn
+	  (define-key ess-mode-map	    ess-S-assign-key nil)
+	  (define-key inferior-ess-mode-map ess-S-assign-key nil))
+      ;; else : "force" or current-key is "nil", i.e. default
+      (define-key ess-mode-map		ess-S-assign-key insert-S-assign)
+      (define-key inferior-ess-mode-map ess-S-assign-key insert-S-assign))))
+
 (defun ess-smart-underscore ()
   "Smart \"_\" key: insert `ess-S-assign', unless in string/comment.
 If the underscore key is pressed a second time, the assignment
@@ -625,14 +656,14 @@ an underscore is always inserted. "
   (interactive "P")
   (require 'ess-mode)
   (require 'ess-inf)
-  (let ((uscore (lookup-key ess-mode-map "_")))
-    (if (and uscore
-	     ;; (stringp uscore) (string= uscore ess-S-assign)
+  (let ((current-key (lookup-key ess-mode-map "_")))
+    (if (and current-key
+	     ;; (stringp current-key) (string= current-key ess-S-assign)
 	     (not force))
 	(progn
 	 (define-key ess-mode-map	   "_" nil); 'self-insert-command
 	 (define-key inferior-ess-mode-map "_" nil))
-      ;; else : "force" or uscore is "nil", i.e. default
+      ;; else : "force" or current-key is "nil", i.e. default
       (define-key ess-mode-map		"_" 'ess-smart-underscore)
       (define-key inferior-ess-mode-map "_" 'ess-smart-underscore))))
 
@@ -641,10 +672,15 @@ an underscore is always inserted. "
 (ess-toggle-underscore 'force-to-S-assign)
 
 (defun ess-add-MM-keys ()
-  "Define MM's user keys, currently only \\<ess-mode-map>\\[ess-insert-function-outline]."
+  "Define MM's user keys, currently \\<ess-mode-map>\\[ess-insert-function-outline], and
+ \\<inferior-ess-mode-map>\\[ess-execute-screen-options]."
   (interactive)
-  (require 'ess-mode)
-  (define-key ess-mode-map "\C-cf" 'ess-insert-function-outline))
+  (require 'ess-mode); typically unnecessary
+  (require 'ess-inf); dito
+  (define-key ess-mode-map          "\C-cf" 'ess-insert-function-outline)
+  (define-key inferior-ess-mode-map "\C-cw" 'ess-execute-screen-options)
+  )
+
 
 (defun ess-dump-args-and-go (Sfunc) ; &optional buff)
   "Dump the function name, with arguments, to a buffer for editing.
@@ -660,7 +696,8 @@ and I need to relearn emacs lisp (but I had to, anyway."
 	 (buf (ess-execute (format "args(%s)" Sfunc) t buffname)))
     (pop-to-buffer buf)
     (message "here yet?")
-    (replace-string "function" Sfunc)
+    (while (search-forward "function" nil t)
+      (replace-match Sfunc nil t))
     (ess-setq-vars-local ess-customize-alist); (current-buffer))
     (setq major-mode 'ess-mode)
     (use-local-map ess-mode-map)
