@@ -60,6 +60,9 @@
 (require 'make-regexp)  ; it's now local to the directory.
 ;;(load-library "make-regexp") ;; this is necessary for
 			     ;; ado-set-font-lock-keywords
+;; only needed in Emacs >= 22.x and newish Xemacsen:
+(unless (boundp 'c-emacs-features)
+  (require 'cc-vars));; for syntax-table
 
 ;(setq max-lisp-eval-depth 500)
 (eval-when-compile
@@ -87,8 +90,23 @@ regexp-search, and so specials should be quoted.
   (modify-syntax-entry ?\$ "." STA-syntax-table)
   (modify-syntax-entry ?` "(\'" STA-syntax-table)
   (modify-syntax-entry ?\' ")`" STA-syntax-table)
-  (modify-syntax-entry ?/ ". 14" STA-syntax-table)
-  (modify-syntax-entry ?* ". 23" STA-syntax-table)
+  ;;--------- begin cut-and-paste from  lisp/progmodes/c-langs.el
+  (cond
+   ;; XEmacs 19, 20, 21
+   ((memq '8-bit c-emacs-features)
+    (modify-syntax-entry ?/  ". 1456" STA-syntax-table)
+    (modify-syntax-entry ?*  ". 23"   STA-syntax-table))
+   ;; Emacs 19, 20, 21
+   ((memq '1-bit c-emacs-features)
+    (modify-syntax-entry ?/  ". 124b" STA-syntax-table)
+    (modify-syntax-entry ?*  ". 23"   STA-syntax-table))
+   ;; incompatible
+   (t (error "CC Mode is incompatible with this version of Emacs"))
+   )
+  (modify-syntax-entry ?\n "> b"  STA-syntax-table)
+  ;; Give CR the same syntax as newline, for selective-display
+  (modify-syntax-entry ?\^m "> b" STA-syntax-table)
+  ;;--------- end cut-and-paste ------------------
   (modify-syntax-entry ?+ "." STA-syntax-table)
   (modify-syntax-entry ?- "." STA-syntax-table)
   (modify-syntax-entry ?= "." STA-syntax-table)
